//*************************************************
// modulo: settings.h
// autore: Longhi Ferdinando
// data: 08/06/2012
// descrizione: modulo per centralina per automatizzare le persiane
// picmicro: PIC16F88
// clock: 8MHz interno
// NOTE:gestione della velocit con PWM
//*************************************************


// definisco le porte con termini facili da ricordare


#define Out1	RA0	// uscita per apertura prima anta
#define Out2	RA1	// uscita per apertura seconda anta
#define Out3	RA2	// uscita per chiusura seconda anta
#define Out4	RA3	// uscita per chiusura prima anta
#define Amp		RA4	// Ingresso per maperostop. Se un motore va in blocco
#define Pul		RB0	// Ingresso pulsante Apre/blocca/Chiudi
#define InPrg	RB1	// Ingresso per programmare indirizzo RS485
#define OutPWM	RB3	// uscita PWM per rallentamento
#define LedPrg	RB4 // uscita per LED modalit programmazione 
#define EN		RB6 // uscita per abilitare la trasmissione su Bus 485
unsigned int duty=0;//valore duty cycle CCP1
unsigned int ValDuty=100;//valore duty cycle
unsigned short Time =0;//tempo che passa
unsigned char Sec=0;//variabile per il conteggio dei secondi
unsigned char TimeAmp=0;//variabile per il conteggio dei secondi in aperostop
unsigned char TimeRal=0;//variabile per il conteggio dei secondi di rallentamento
unsigned char TRal=5;//tempo di rallentamento
unsigned char Time1=5;//tempo apertura anta 1
unsigned char Time2=6;//tempo apertura anta 2
unsigned char Time3=7;//tempo chiusura anta 2
unsigned char Time4=8;//tempo chiusura anta 1
unsigned char Arb=50;//tempo dell'antirimbalzo
unsigned char EEvalue;//valore letto nella EEprom
unsigned char EEaddress;//valore letto nella EEaddress
long timeout=0;//variabile che gestisce il time out dei dati ricevuti da RS485
int Dest=0;	//indirizzo dispositivi destinatario
int Address=255;	//indirizzo di questo dispositivo
int Group=1;//gruppo di appartenenza
int Command=255;		//Valore che identifica il comando 
int Data1=0;		//dato da ricevere o inviare
int Data2=0;		//dato da ricevere o inviare
int AddressOld=0;	//indirizzo vecchio del dispositivo
int State=0;	//stato in cui si trova il modulo
unsigned char Input[6]=0; // variabile per contenere il buffer di ricezione seriale

bit Brk=0;//flag per uscire dalla routine while
bit Apro=0;//flag per comando apre gestito dalla RS485
bit Chiudo=0;//flag per comando chiude gestito dalla RS485
bit ApCh=0;//flag per comando apre/chiude gestito dalla RS485

void settings(void)
	{
//Usero' le porte A solo come digitali e non con analogiche
	ANSEL=0b00000000;
// Abilito l'scillatore interno pag. 40 del datasheet PIC16F88
	OSCCON=0b01111100;//Freq.=8Mhz

// Posso correggere l'errore dell'oscillatore interno pag. 88 del datasheet PIC16F88
	OSCTUNE=0b00000000;//Non correggo

	
// Impostazione della porta seriale
RCIE=1; // interrupt di ricezione su seriale attivato
TXSTA=0b00000100;
RCSTA=0b10000000;
SPBRG=12;//con osc. interno a 8 MHz baud rate di 9600 asincrono
// Impostazione Interrupt
 INTCON=0b11100000;
 // bit 0 -> RBIF - Flag interrupt su porte B
 // bit 1 -> INTF - Flag interrupt su RB0/INT
 // bit 2 -> T0IF - Flag interrupt su Timer0
 // bit 3 -> RBIE, Interrupt su porte B disattivato
 // bit 4 -> INTE, Interrupt su porta RB0/INT disattivato
 // bit 5 -> TMR0IE, Interrupt su Timer0 attivato
 // bit 6 -> PEIE, Interrupt di periferica attivato
 // bit 7 -> GIE, Gestione Interrupt attiva

	
// Abilito l'interrupt 
	TMR0IE=1; // abilito la gestione dell'interrupt sull'overflow del Timer0
	GIE=1; // abilito la gestione generale degli interrupt

// Definisco il registro OPTION pag. 18 del datasheet PIC16F88
OPTION_REG=0b10000100;
// Impostazione Registro Opzioni
// bit 0 -> PS0    Prescaler Rate Select bit 0
// bit 1 -> PS1    Prescaler Rate Select bit 1
// bit 2 -> PS2    Prescaler Rate Select bit 2
// bit 3 -> PSA    Prescaler assegnato al Timer0 (1=al Watchdog Timer)
// bit 4 -> T0SE   Incremento Timer0 su transizione: 0=low->high 1=high->low
// bit 5 -> T0CS   Clock Timer0 da clock interno (1=su transizione pin T0CKI)
// bit 6 -> INTEDG Interrupt (INT) edge (1=salita 0=discesa)
// bit 7 -> RBPU   Resistenze pull-up su porta B (1=off 0=on)

	TRISA=0b11110000;		
// Impostazione porta RA
// RA0  -> Out1 per apertura anta 1
// RA1  -> Out2 per apertura anta 2
// RA2  -> Out3 per chiusura anta 2
// RA3  -> Out4 per chiusura anta 1
// RA4  -> Ingresso per amperostop. Se 1 motore in blocco
// RA5  -> Ingresso disponibile - Pu essere solo ingresso
// RA6  -> Ingresso disponibile
// RA7  -> Ingresso disponibile

	TRISB=0b10000111;		
// Impostazione porta RB
// RB0  -> Ingresso pulsante Apre/blocca/Chiudi
// RB1  -> Ingresso per programmazione ind. RS485
// RB2  -> Ingresso per RX RS485
// RB3  -> Out per PWM
// RB4  -> Out per LED di programmazione
// RB5  -> Out per TX Bus 485
// RB6  -> Out6 abilita la trasmissione in RS485
// RB7  -> Ingresso disponibile

	
	TMR0=194; // Imposto Timer0 per avere un interrupt ogni micro secondo
	}
